@@ -12,11 +12,13 @@ this code is Public Domain
 #include <QPainter>
 #include <QTextCharFormat>
 
+
 inline int tropical_year (int year)
 {
   return 1 + (year % 19);
 }
 
+
 int moon_phase_leueshkanov (int year, int month, int day)
 {
   int L = tropical_year (year);
@@ -51,12 +53,13 @@ int moon_phase_trig2 (int year, int month, int day)
   int r = (j1 - jd + 30) % 30;
   if (r == 0)
      r = 30;
+  
  return r;
 }
 
 
-//This simply mods the difference between the date and a known new moon date (1970-01-07) by the length of the lunar period.
-//For this reason, it is only valid from 1970 onwards.
+/*This simply mods the difference between the date and a known new moon date (1970-01-07) by the length of the lunar period.
+For this reason, it is only valid from 1970 onwards.*/
 
 int moon_phase_simple (int year, int month, int day)
 {
@@ -67,10 +70,12 @@ int moon_phase_simple (int year, int month, int day)
   return floor (phase / (24 * 3600)) + 1;
 }
 
+
 /*
 Conway
 This is based on a 'do it in your head' algorithm by John Conway. In its current form, it's only valid for the 20th and 21st centuries, but I'm sure John's got refinements. :)
 */
+
 int moon_phase_conway (int year, int month, int day)
 {
   int r = year % 100;
@@ -124,19 +129,19 @@ int moon_phase_trig1 (int year, int month, int day)
 
   while (jday < thisJD)
         {
-		 double F = F0 + 1.530588 * phase;
-		 double M5 = (M0 + phase * 29.10535608) * degToRad;
-		 double M6 = (M1 + phase * 385.81691806) * degToRad;
-		 double B6 = (B1 + phase * 390.67050646) * degToRad;
-		 F -= 0.4068 * sin (M6) + (0.1734 - 0.000393 * T) * sin(M5);
-		 F += 0.0161 * sin (2 * M6) + 0.0104 * sin (2 * B6);
-		 F -= 0.0074 * sin (M5 - M6) - 0.0051 * sin(M5 + M6);
-		 F += 0.0021 * sin (2 * M5) + 0.0010 * sin(2 * B6 - M6);
-		 F += 0.5 / 1440;
-		 oldJ = jday;
-		 jday = J0 + 28 * phase + floor(F);
-		 phase++;
-	    }
+         double F = F0 + 1.530588 * phase;
+         double M5 = (M0 + phase * 29.10535608) * degToRad;
+         double M6 = (M1 + phase * 385.81691806) * degToRad;
+         double B6 = (B1 + phase * 390.67050646) * degToRad;
+         F -= 0.4068 * sin (M6) + (0.1734 - 0.000393 * T) * sin(M5);
+         F += 0.0161 * sin (2 * M6) + 0.0104 * sin (2 * B6);
+         F -= 0.0074 * sin (M5 - M6) - 0.0051 * sin(M5 + M6);
+         F += 0.0021 * sin (2 * M5) + 0.0010 * sin(2 * B6 - M6);
+         F += 0.5 / 1440;
+         oldJ = jday;
+         jday = J0 + 28 * phase + floor(F);
+         phase++;
+        }
 
   return (thisJD - oldJ) % 30;
 }
@@ -145,7 +150,6 @@ int moon_phase_trig1 (int year, int month, int day)
 CCalendarWidget::CCalendarWidget (QWidget *parent, const QString &a_dir_days): QCalendarWidget (parent)
 {
   dir_days = a_dir_days;
-
   moon_phase_algo = MOON_PHASE_TRIG2;
   moon_mode = false;
   moon_tiles.load (":/images/moon-phases.png");
