@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2013 by Peter Semiletov                                          *
+ *   2007-2014 by Peter Semiletov                                          *
  *   tea@list.ru                                                           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -16,7 +16,7 @@
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+ **************************************************************************/
 
 /* some code by
 Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
@@ -24,8 +24,8 @@ Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
 
 /*
 code from qPEditor:
-*   Copyright (C) 2007 by Michael Protasov
-*   mik-protasov@anyqsoft.com */
+Copyright (C) 2007 by Michael Protasov, mik-protasov@anyqsoft.com
+*/
 
 /*
 Diego Iastrubni <elcuco@kde.org> //some GPL'ed code from new-editor-diego-3,
@@ -39,7 +39,6 @@ code from qwriter:
 */
 
 
-
 #include "document.h"
 #include "utils.h"
 #include "gui_utils.h"
@@ -100,7 +99,7 @@ void CDocument::update_title (bool fullname)
   if (fullname)
      w->setWindowTitle (file_name);
   else
-     w->setWindowTitle (QFileInfo (file_name).fileName());
+      w->setWindowTitle (QFileInfo (file_name).fileName());
 }
 
 
@@ -114,6 +113,9 @@ void CDocument::reload (const QString &enc)
 bool CDocument::open_file (const QString &fileName, const QString &codec)
 {
   CTio *tio = holder->tio_handler.get_for_fname (fileName);
+  
+  if (! tio)
+      return false;
 
   if (fileName.contains (holder->dir_config))
       tio->charset = "UTF-8";
@@ -159,6 +161,9 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
 bool CDocument::save_with_name (const QString &fileName, const QString &codec)
 {
   CTio *tio = holder->tio_handler.get_for_fname (fileName);
+  
+  if (! tio)
+      return false;
 
   if (fileName.contains (holder->dir_config))
       tio->charset = "UTF-8";
@@ -229,22 +234,24 @@ CDocument::CDocument (QObject *parent): QObject (parent)
 
   //qDebug() << "Q_OS_MAC";
 
-
 #endif
 
   //qDebug() << "CDocument()";
-
+/*
   if (eol == "\n")
     qDebug() << "LF";
   if (eol == "\r\n")
     qDebug() << "CRLF";
   if (eol == "\r")
-    qDebug() << "CR";
+    qDebug() << "CR";*/
 }
 
 
 CDocument::~CDocument()
 {
+  if (file_name.endsWith (".notes") && textEdit->document()->isModified()) 
+     save_with_name_plain (file_name);
+  else
   if (file_name.startsWith (holder->dir_config) && textEdit->document()->isModified()) 
      save_with_name_plain (file_name);
   else
@@ -260,6 +267,7 @@ CDocument::~CDocument()
      }
 
   if (! file_name.startsWith (holder->dir_config))
+  if (! file_name.endsWith (".notes")) 
      {
       holder->add_to_recent (this);
       holder->update_recent_menu();
@@ -486,7 +494,7 @@ QString CDocument::get_filename_at_cursor()
 //     qDebug() << "x = " << x;
      
      result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
-     qDebug() << "in cur dir: " << result;
+     //qDebug() << "in cur dir: " << result;
      return result;
     }
   else
