@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyleft 2007-2014 by Peter Semiletov                            *
- *   peter.semiletov@gmail.com                                             *
+ *   2007-2014 by Peter Semiletov                                          *
+ *   tea@list.ru                                                           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,18 +16,13 @@
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+ **************************************************************************/
 
 /*
-** Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
-**
-** This file is part of the example classes of the Qt Toolkit.
-**
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
 */
-/*
+
+/* 
 Diego Iastrubni <elcuco@kde.org> //some GPL'ed code from new-editor-diego-3, found on qtcentre forum
 */
 
@@ -248,12 +243,9 @@ public:
   QHash <QString, QString> fnameswoexts;
   
   QString eol;
-
   
   document_holder *holder;
   CSyntaxHighlighter *highlighter;
-  
-  
   CTEAEdit *textEdit;
 
   QStringList labels;
@@ -268,27 +260,27 @@ public:
   CDocument (QObject *parent = 0);
   ~CDocument();
 
-  QString get_selected_text() const;
-  void set_selected_text (const QString &value);
+  Q_INVOKABLE QString get_selected_text() const;
+  Q_INVOKABLE void set_selected_text (const QString &value);
 
   void create_new();
-  void set_tab_caption (const QString &fileName);
-  bool save_with_name (const QString &fileName, const QString &codec);
-  bool save_with_name_plain (const QString &fileName);
-  void goto_pos (int pos);
-  QString get_filename_at_cursor();
-  QStringList get_words();
-  void set_hl (bool mode_auto = true, const QString &theext = "txt");
-  bool open_file (const QString &fileName, const QString &codec);
-  void insert_image (const QString &full_path);
-  void set_markup_mode();
-  void reload (const QString &enc);
-  int get_tab_idx();
-  QString get_triplex();
-  void update_status();
-  void update_title (bool fullname = true);
+  Q_INVOKABLE void set_tab_caption (const QString &fileName);
+  Q_INVOKABLE bool save_with_name (const QString &fileName, const QString &codec);
+  Q_INVOKABLE bool save_with_name_plain (const QString &fileName);
+  Q_INVOKABLE void goto_pos (int pos);
+  Q_INVOKABLE QString get_filename_at_cursor();
+  Q_INVOKABLE QStringList get_words();
+  Q_INVOKABLE void set_hl (bool mode_auto = true, const QString &theext = "txt");
+  Q_INVOKABLE bool open_file (const QString &fileName, const QString &codec);
+  Q_INVOKABLE void insert_image (const QString &full_path);
+  Q_INVOKABLE void set_markup_mode();
+  Q_INVOKABLE void reload (const QString &enc);
+  Q_INVOKABLE int get_tab_idx();
+  Q_INVOKABLE QString get_triplex();
+  Q_INVOKABLE void update_status();
+  Q_INVOKABLE void update_title (bool fullname = true);
 
-  void update_labels();
+  Q_INVOKABLE void update_labels();
 };
 
 
@@ -328,21 +320,21 @@ public:
   
   ~document_holder();
 
-  CDocument* create_new();
-  CDocument* open_file (const QString &fileName, const QString &codec);
-  CDocument* open_file_triplex (const QString &triplex);
-  CDocument* get_document_by_fname (const QString &fileName);
+  Q_INVOKABLE CDocument* create_new();
+  Q_INVOKABLE CDocument* open_file (const QString &fileName, const QString &codec);
+  Q_INVOKABLE CDocument* open_file_triplex (const QString &triplex);
+  Q_INVOKABLE CDocument* get_document_by_fname (const QString &fileName);
 
   void reload_recent_list();
 
-  void save_to_session (const QString &fileName);
-  void load_from_session (const QString &fileName);
+  Q_INVOKABLE void save_to_session (const QString &fileName);
+  Q_INVOKABLE void load_from_session (const QString &fileName);
   void load_palette (const QString &fileName);
 
   void close_by_idx (int i);
-  void close_current();
-  void apply_settings();
-  void apply_settings_single (CDocument *d);
+  Q_INVOKABLE void close_current();
+  Q_INVOKABLE void apply_settings();
+  Q_INVOKABLE void apply_settings_single (CDocument *d);
 
   void add_to_recent (CDocument *d);
   void update_recent_menu();
@@ -350,21 +342,13 @@ public:
   //void add_to_current_files (CDocument *d);
   void update_current_files_menu();
 
-  
-  CDocument* get_current();
+  Q_INVOKABLE CDocument* get_current();
+ 
 
 public slots:
-
+ 
   void open_recent();
   void open_current();
-  
-/*    
-public signals:
-  
-  void signal_file_open (const QString &fname);  
-  void signal_file_rename (const QString &oldname, const QString &newname);  
-  void signal_file_close (const QString &fname);  
-*/
 };
 
 
