@@ -1,6 +1,6 @@
  /**************************************************************************
- *   2007-2014 by Peter Semiletov                            *
- *   peter.semiletov@gmail.com                                             *
+ *   2007-2014 by Peter Semiletov                                          *
+ *   tea@list.ru                                                           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +16,7 @@
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+ **************************************************************************/
 
 #include "fman.h"
 #include "utils.h"
@@ -28,6 +28,7 @@
 #include <QMimeData>
 #include <QDebug>
 #include <QApplication>
+#include <QDateTime>
 
 
 void CFMan::dir_up()
