@@ -22,6 +22,7 @@
 #include "logmemo.h"
 
 #include <QTime>
+#include <QTextCursor>
 
 
 CLogMemo::CLogMemo (QPlainTextEdit *m)
@@ -29,6 +30,8 @@ CLogMemo::CLogMemo (QPlainTextEdit *m)
   memo = m;
   setObjectName ("logmemo");
   memo->setFocusPolicy (Qt::ClickFocus);
+  memo->setUndoRedoEnabled (false);
+  memo->setReadOnly (true);
 }
 
 
