@@ -21,7 +21,11 @@
 #ifndef LOGMEMO_H
 #define LOGMEMO_H
 
-#include <QtGui>
+//#include <QtGui>
+
+#include <QObject>
+#include <QPlainTextEdit>
+#include <QString>
 
 
 class CLogMemo: public QObject
