@@ -52,6 +52,19 @@
 #include <QProcess>
 
 
+//QML stuff
+#if QT_VERSION >= 0x050000
+
+#include <QQmlEngine>
+#include <QQuickWindow>
+//#include <QJSEngine>
+
+#endif
+
+//
+
+
+
 #ifdef PRINTER_ENABLE
 
 #include <QPrinter>
@@ -59,6 +72,7 @@
 #endif
 
 
+/*
 class CMarkupPair: public QObject
 {
   Q_OBJECT
@@ -68,6 +82,17 @@ public:
   QHash <QString, QString> tags_a;
   QHash <QString, QString> tags_b;
 };
+*/
+
+class CMarkupPair: public QObject
+{
+  Q_OBJECT
+
+public:
+
+  QHash <QString, QString> pattern;
+};
+
 
 
 class CStrIntPair: public QObject
@@ -148,7 +173,13 @@ public:
 
   rvln();
   ~rvln();
+  
+#if QT_VERSION >= 0x050000
 
+  QQmlEngine *qml_engine;
+
+#endif
+  
   int fm_entry_mode; 
 
   QDate date1;
@@ -200,6 +231,12 @@ public:
 
 
   QHash <QString, CMarkupPair*> hs_markup;
+  //QHash <QString, CMarkupPair2*> hs_markup2;
+  
+//   QHash <QString, THashStringPair*> hs_markup2;
+
+  
+  
 
   QToolBar *tb_fman_dir;
   QLabel *l_fman_preview;
@@ -244,8 +281,13 @@ public:
   QString dir_sessions;
   QString dir_hls;
 
-  QString dir_variants;
 
+//#if QT_VERSION >= 0x050000
+
+  QString dir_plugins;
+
+//#endif
+  
   QString dir_snippets;
   QString dir_scripts;
   QString dir_palettes;
@@ -320,7 +362,7 @@ protected:
   bool fman_tv_eventFilter (QObject *obj, QEvent *event);
 
 
-private slots:
+public slots:
 
 /*************************
 main window callbacks
@@ -330,7 +372,7 @@ main window callbacks
   void update_labels_menu();
   void update_labels_list();
 
-  void ed_variants();
+  //void ed_variants();
 
   
   void fm_full_info();
@@ -386,6 +428,9 @@ main window callbacks
   void file_open_program();
   void file_add_to_bookmarks();
   void file_crapbook();
+  
+  void file_notes();
+  
   void file_use_template();
   void file_use_snippet();
   void file_use_palette();
@@ -508,7 +553,7 @@ main window callbacks
   
   void remove_formatting();
 
-  void fn_variants_callback();
+//  void fn_variants_callback();
 
   
 #ifdef SPELLCHECK_ENABLE
@@ -557,6 +602,13 @@ main window callbacks
   void mrkup_mode_choosed();
   void mrkup_header();
   void mrkup_align();
+  
+  void mrkup_align_center();
+  void mrkup_align_left();
+  void mrkup_align_right();
+  void mrkup_align_justify();
+  
+  
   void mrkup_document_weight();
   void markup_ins_image();
   void mrkup_color();
@@ -666,8 +718,13 @@ prefs window callbacks
   void slot_style_currentIndexChanged (const QString &text);
 
   
+#if QT_VERSION >= 0x050000
+  
+  void fn_use_plugin();
 
-private:
+#endif
+  
+public:
 
 /*************************
 main window widgets
@@ -709,6 +766,14 @@ main window widgets
 
   QMenu *menu_fn_sessions;
   QMenu *menu_fn_scripts;
+  
+  
+#if QT_VERSION >= 0x050000
+  
+  QMenu *menu_fn_plugins;
+
+#endif  
+  
   QMenu *menu_markup;
   QMenu *menu_functions;
   QMenu *menu_functions_case;
@@ -848,7 +913,13 @@ prefs window widgets
   void update_sessions();
   void update_palettes();
   void update_view_hls();
+  
+#if QT_VERSION >= 0x050000
+    
+  void update_plugins();
 
+#endif
+  
   void update_hls (bool force = false);
 
   void update_tables();
@@ -875,6 +946,7 @@ prefs window widgets
 
   void createFman();
   void create_markup_hash();
+  //void create_markup_hash2();
 
   void count_substring (bool use_regexp);
 
@@ -884,7 +956,8 @@ prefs window widgets
 
   void fman_convert_images (bool by_side, int value);
  
-  QString fif_get_text();
+  Q_INVOKABLE QString fif_get_text();
+  
   void fn_filter_delete_by_sep (bool mode);
 
   void fman_items_select_by_regexp (bool mode);
@@ -909,7 +982,16 @@ prefs window widgets
 
   
   void load_userfonts();
+  
+#if QT_VERSION >= 0x050000
+  
+  void plugins_init();
+  void plugins_done();
+  
+#endif  
 
+  void markup_text (const QString &mode);
+  
 };
 
 
@@ -925,5 +1007,28 @@ public:
   void saveState (QSessionManager &manager);
 };
 
+#if QT_VERSION >= 0x050000
+
+class CQQuickWindow: public QQuickWindow
+{
+   Q_OBJECT
+   
+public:
+ 
+ 
+ CQQuickWindow(QWindow * parent = 0): QQuickWindow (parent)
+   {;}
+ 
+ QString id;
+
+protected:
+
+//  void closeEvent (QCloseEvent *event);
+  bool event (QEvent *event);
+
+  
+};
+
+#endif
 
 #endif
