@@ -207,7 +207,7 @@ bool CTioODTSpecial::load (const QString &fname)
     
   if (! zipper.read_as_utf8 (fname, "content.xml"))
      {
-      qDebug() << "333";
+      qDebug() << "cannot read content.xml";
       return false;
      }
 
