@@ -1,7 +1,18 @@
 #ifndef TODO_H
 #define TODO_H
 
-#include <QtGui>
+//#include <QtGui>
+
+#include <QObject>
+#include <QDate>
+#include <QTimer>
+#include <QHash>
+#include <QWidget>
+#include <QTextEdit>
+#include <QString>
+#include <QMessageBox>
+
+
 
 class CTodo: public QObject
 {
