@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="de_DE" sourcelanguage="en">
+<TS version="2.0" language="de_DE" sourcelanguage="en">
 <context>
     <name>CAboutWindow</name>
     <message>
@@ -101,7 +101,7 @@ Do you want to save your changes?</source>
 <context>
     <name>CZORWindow</name>
     <message>
-        <source> scaled to</source>
+        <source>scaled to: </source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1605,15 +1605,36 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Variants</source>
+        <source>Notes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>variants</source>
+        <source>Center</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>variants file %1 is not exist</source>
+        <source>Justify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plugins</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>It seems that %1 contains TEA plugin
+Do you want to install it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>There is no plugin file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;Error:&lt;/b&gt; </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>put your notes (for this file) here and they will be saved automatically</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
