@@ -312,8 +312,17 @@ bool CFTypeChecker::check (const QString &fname)
 
 bool char_is_shit (const QChar &c)
 {
-  if (! c.isNull() && ! c.isLetter())
+  /*if (c == 0xfeff00ab)
+     return false;
+  
+  if (c == 0xfeff00bb)
+       return false;*/
+
+  
+ if (! c.isNull() && ! c.isLetter())
      return true;
 
+  
+  
   return false;
 }
